* migstat08_stata.zip: migstat08.do 
* =============================================================================

* Stata/MP 12.1 for Windows


clear
capture log close
set more off
* set memory 800m
set dp comma
set linesize 250

* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */ 
cd '<Arbeitsverzeichnis>'

log using migstat2008.log, replace text

/* ===========================================================================
Programmname: migstat08.do

STATA-PROGRAMM ZUR TYPISIERUNG DES MIGRATIONSSTATUS IM MIKROZENSUS 2008

Programmautor/en:
  SAS-Originalprogramm: Gunter Brueckner (Statistisches Bundesamt; 
     Referat F 204 Migration und integration, Wohnen)
  Anpassungen an Scientific Use File Mikrozensus 2008: Delia Jaeger,
     Bernhard Schimpl-Neimanns (GESIS, GML)

Programmzweck:
   Dieses Programm dient der Replikation des Migrationsstatus, Variable MIG, 
   und der Staatsangehoerigkeit zum Migrationsstatus (MIGS) im Scientific 
   Use File (SUF) des Mikrozensus 2008.
   Die Programme basieren auf den SAS-Programmen zum Original-Mikrozensus des
   Statistischen Bundesamtes und wurden an Recodierungen des SUF angepasst.
   Bei der Replikation der Variablen Staatsangehoerigkeit zum Migrationsstatus 
   (MIGS) ist zu beachten, dass aus Gruenden des Datenschutzes Angaben zur 
   zweiten Staatsangehoerigkeit (EF370) nur rudimentaer vorhanden sind. Des 
   Weiteren sind die zur Konstruktion von MIGS verwendeten Variablen
       EF369 1. Staatsangehoerigkeit 
   und EF374 Staatsangehoerigkeit: vor Einbuergerung/Zuzug als Spaetaussiedler
   unterschiedlich codiert. Die Replikation ist deshalb nur eingeschraenkt 
   moeglich.

Weiterfuehrende Programmbeschreibung: 
   Jaeger, Delia und Bernhard Schimpl-Neimanns: Typisierung des 
    Migrationshintergrundes in den Mikrozensus Scientific-Use-Files 2005-2009. 
    GESIS-Technical Report Nr. 2012/08. Mannheim: GESIS. URL: 
    http://www.gesis.org/fileadmin/upload/forschung/publikationen/gesis_reihen/
    gesis_methodenberichte/2012/TechnicalReport_2012-08.pdf.

Download dieser Datei:
   http://www.gesis.org/missy/studie/klassifikationen/konzepte-und-definitionen/
   migrationshintergrund/migstat08_stata.zip

Siehe auch Anhang 1: Personen mit Migrationshintergrund - Auf dem Weg zu einer 
   definitorischen Abgrenzung - S. 398-407 in: Statistisches Bundesamt, 2011: 
   Bevoelkerung mit Migrationshintergrund. Ergebnisse des Mikrozensus 2009. 
   Fachserie 1 Reihe 2.2. Wiesbaden. URL:
   https://www.destatis.de/DE/Publikationen/Thematisch/Bevoelkerung/
   MigrationIntegration/Migrationshintergrund2010220097004.pdf?__blob=
   publicationFile; letzter Zugriff: 24.07.2012.

Programmstruktur:
   0. Datenvorbereitung
   1. Grundtypisierung des Migationshintergrundes
   2. Identifikation von 3-Generationen-Haushalten
   3. Endtypisierung der Grosseltern
   4. Endtypisierung der Eltern
   5. Endtypisierung Befragte
   6. Umsetzung von Zeitreihenkompatibilitaet (entfaellt im MZ 2008)
   7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse

Programmstatus:
  Getestet mit Stata/MP 12.1 for Windows und dem Scientific Use File 
  Mikrozensus 2008, Version 2 vom 06. 04. 2011. Stand: Juli 2012
============================================================================ */

* Variablenauswahl Scientific Use File Mikrozensus 2008, Version 2
*   Lokalen Dateinamen inkl. Verzeichnis in <> eintragen
use  EF1 EF3 EF4 EF5a EF5b EF8 EF9 EF12 EF30 EF31 EF37 EF44 EF46 EF47 EF50 EF51 ///
     EF52 EF53 EF54 EF55 EF366 EF367 EF368 EF369 EF370 EF371 EF372 EF373 EF374  ///
     EF952 mig migs ///
  using <mz2008.dta>, replace

* =====================================================================
* 0. Datenvorbereitung

* Satznummer Ausgangsfile 
gen ID = _n
label var ID "Satznummer Ausgangsfile mz2008.dta"

* Variablennamen Gross- => Kleinschreibung
renpfix EF ef

* Value Label mit Code
numlabel _all, add mask("[#] ")


/* Neue HHNR bilden, um Haushalte des Jahresbestandes (EF5b=0)
   und Jahresueberhanges (EF5b=1) einfach zu beruecksichtigen; 
   ef12 Berichtsquartal */
gen v4=ef4*100 + ef5b*10 + ef12
label var v4 "HHNR EF4*100 + ef5b*10 + ef12"

* Sortierfolge
sort ef1 ef3 v4 ef5a


* Sichern SUF-Originalvariable
rename mig   mig_o
rename migs  migs_o
rename ef374 ef374_o

/* Staatsangehoerigkeit
---------------------------------------------------------------------------
ZU BEACHTEN: Aufgrund unterschiedlicher Codierungen bei der Anonymisierung
des Scientific Use Files bei den Variablen EF369 und EF374 sowie im Vergleich
zu den Originaldaten kann die Staatsangehoerigkeit zum Migrationsstatus 
(SA_erw, MIGS) nicht bzw. nur naeherungsweise repliziert werden. 
1. Harmonisierung Staatsangehoerigkeit: Anpassung von EF374 an EF369 und MIGS 
   EF374_O Originalfassung 
2. EF370 2. Staatsangehoerigkeit enthaelt nur die Information
         0 Auslaender mit nur einer Staatsangehoerigkeit
         1 Nur deutsche Staatsangehoerigkeit / Deutsche und weitere 
           Staatsangehoerigkeit
   Die einzelnen Staatsangehoerigkeiten sind nicht ausgewiesen.
   Um Fehlinterpretationen durch die Zuweisung "SA2=ef370" zu vermeiden, 
   wird diese unten deaktiviert. 
*/

recode ef374_o ( 3 = 25)      /// 25 = 3/25: Bulgarien(3); Rumaenien(25)
               ( 8 =  4)      ///  4 = 4/8/27: Daenemark(4); Finnland(8); Schweden(27)
               ( 1 = 21)      /// 21 = 1/18/21: Belgien(1); Luxemburg(18); Niederlande(21)
               (7 15 17 = 31) /// 31 = 7/15/17/19/31/37: Estland(7); Lettland(15); Litauen(17); Malta(19); Slowenien(31); Zypern(37)
               (30 = 33)      /// 33 = 30/33: Slowakei(30); Tschechische Republik(33)
               (98 = 55),     /// 55 = 55/98: Uebrige Welt(55); Staatenlos(98)
               gen(ef374) copyrest
label var ef374 "Staatsangehoerigkeit: vor Einbuergerung/Zuzug als Spaetaussiedler - recodiert"
format ef374 %2.0f


/* ============================================================================
1. Grundtypisierung des Migrationshintergrundes 
   Es werden zunaechst nur die Angaben der Person selbst zur Typisierung 
   verwendet. Die erste Typisierung erfolgt nach Angaben zur 
   Staatsangehoerigkeit (deutsch / nicht-deutsch) und Geburtsland 
   (Ausland / Inland).
   Zur Unterscheidung der Gruppe eingebuergerter Zuwanderer (MIG=31) nach 
   einem evtl. Status als Spaetaussiedler wird abschliessend geprueft ob der 
   Ehegatte, der Vater oder die Mutter im Haushalt einen 
   Spaetaussiedlerstatus besitzt.
   Trifft dies zu, erfolgt eine Rekodierung (Plausibilisierung) 
   von MIG=31 'zugewanderter eingebuergerter Auslaender'
   zu  MIG=22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuerg)' 
*/

generate gebj=ef47
label var gebj "Geburtsjahr"
format gebj %4.0f

generate brdborn = ef366
label var brdborn "Geburtsland: BRD (EF366)"
label def brdborn 1 "Ja, hier geboren" 8 "Nein, zugezogen" 9 "ohne Angabe", add modify
format brdborn %1.0f
label val brdborn brdborn

recode brdborn (1=0) (8=1) (*=9), gen(zuzug)
label var zuzug "Zuzug ex BRDBorn, EF366"
label def zuzug 0 "kein Zuzug" 1 "foreign born" 2 "Zuzug nach 6+ Mo im Ausland:= in D geboren" 9 "k.A.", add modify
format zuzug %1.0f
label val zuzug zuzug

recode ef367 (1949=1949) (9999=9) (0=0), gen(jzuzug) copyrest
label def jzuzug 1949 "Zuzug vor 1950" 9 "o.A. zum Zuzugsjahr"  0 "kein Zuzugsjahr sinnvoll", add modify
label val jzuzug jzuzug

replace zuzug  = 2 if (brdborn==1 & jzuzug>9)
replace jzuzug = 9 if (brdborn==8 & jzuzug<10)

* Kontrolle
* tab1 brdborn zuzug jzuzug, miss

* Initialisierung
gen mig=.     // Migrationsstatus
gen ausl=.    // Auslaender
gen sadopp=.  // Doppelte Staatsangehoerigkeit
gen sa=.      // Aktuelle Staatsangehoerigkeit
gen sa1=.     // Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370
gen sa2=.     // Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370)
gen sa3=.     // Staatsangehoerigkeit vor Einbuergerung 
gen spauss=.  // Spaetaussiedler
gen eingeb=.  // Eingebuergert
gen jeinb=.   // Jahr der Einbuergerung
gen sa_erw=.  // Erweiterte aktuelle Staatsangehoerigkeit

* nur deutsche Staatsangehoerigkeit (SA)
replace ausl=0   if ef368==1
replace sadopp=0 if ef368==1
replace sa1=0    if ef368==1
replace sa2=.    if ef368==1

* deutsche und auslaendische SA 
replace ausl=0    if ef368==2
replace sadopp=1  if ef368==2
replace sa1=0     if ef368==2
replace sa2=ef369 if ef368==2

* nur auslaendische SAs 
replace ausl=1     if ef368==8 // ef368!=1 & ef368!=2
replace sa1=ef369  if ef368==8
replace sadopp=0   if ef368==8 & ef370==0 // ef370=0: Ausl. mit nur einer Staatsangeh.
replace sa2=.      if ef368==8 & ef370==0
replace sadopp=1   if ef368==8 & ef370!=0 
* DEAKTIVIERT replace sa2=ef370  if ef368==8 & ef370!=0

* Kontrolle
* tab1 ausl sadopp sa1 sa2, miss

/* ####### Eingebuergerte/Spaetaussiedler und Staatsangehoerigkeit davor ####### */
* Spaetaussiedler (spauss) mit Einbuergerung (eingeb)
replace spauss=1    if ef372==2
replace eingeb=1    if ef372==2
replace jeinb=9     if ef372==2 & ef373==0  // Einbuergerungsjahr 
replace jeinb=ef373 if ef372==2 & ef373!=0
replace sa3=.       if ef372==2 & ef374==0
replace sa3=ef374   if ef372==2 & ef374!=0
replace sa2=.       if ef372==2 & ef369==0
replace sa2=ef369   if ef372==2 & ef369!=0

* Spaetaussiedler ohne Einbuergerung (spauss)
replace spauss=1    if ef372==4 
replace eingeb=0    if ef372==4
replace jeinb=.     if ef372==4
replace sa3=.       if ef372==4 & ef374==0
replace sa3=ef374   if ef372==4 & ef374!=0
replace sa2=.       if ef372==4 & ef369==0
replace sa2=ef369   if ef372==4 & ef369!=0

* sonstige Einbuergerung 
replace spauss=0    if ef372==3
replace eingeb=1    if ef372==3
replace jeinb=9     if ef372==3 & ef373==0
replace jeinb=ef373 if ef372==3 & ef373!=0
replace sa3=.       if ef372==3 & ef374==0
replace sa3=ef374   if ef372==3 & ef374!=0

* Deutsch durch Geburt 
replace spauss=0  if ef372<2
replace eingeb=0  if ef372<2
replace jeinb=.   if ef372<2
replace sa3=0     if ef372<2
replace sa2=.     if ef372<2 & ef369==0
replace sa2=ef369 if ef372<2 & ef369!=0

* KONTROLLE  
* tab1 sa1 sa2 sa3, miss

/* ####### Grundtypisierung des Migrationshintergrundes ####### 
   MIG: Migrationstypus
   1. Stelle: Migrationstyp: 
      1=vertrieben;
      2=als Deutsche/r bzw. Spaetaussiedler zugewandert;
      3=eingebrgert;
      4=Auslnder/in;
   2. Stelle: Generation: 
      1=im Ausland geboren, 
      2=in Deutschland geboren 

    MIG:
      11=Vertriebene vor 1950;
      21=Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung);
      22=Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung);
      25=(Spaet-)Aussiedler (mit Einbuergerung);
      29=(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr;
      31=zugewanderte/r eingebuergerte/r Auslaender/in;
      32=nicht zugewanderte/r eingebuergerte/r Auslaender/in;
      41=zugewanderte/r Auslaender/in;
      42=nicht zugewanderte/r Auslaender/in;
      77=uneindeutig ob deutsch, vertrieben oder Spaetaussiedler 
      99=fehlende/unvollstaendige Angaben 
   SA: aktuelle Staatsangehoerigkeit

   SA_erw: erweiterte aktuelle Staatsangehoerigkeit
           gewonnen aus SA1 - SA3 nach folgenden Regeln:
      0=deutsch (bei MIG=0, 11);
       =SA1 (bei Mig=41,42);
       =SA3 (bei Mig=21,25,29,31,32 und SA3<>.);
       =SA2 (bei MIG=21,25,29,31,32 und SA3=.und SA2<>.)
       =99 (bei MIG=21,25,29,31,32 und SA2=. und SA3=. oder bei MIG=77,99) */

* A)  im Ausland geboren 
* A1) als Auslaender zugewandert
replace mig=41     if brdborn==8 & ausl==1
replace sa=sa1     if brdborn==8 & ausl==1 & mig==41
replace sa_erw=sa1 if brdborn==8 & ausl==1 & mig==41

* ... als Deutscher zugewandert 
* A2) Spaetaussiedler/in
replace mig=25     if brdborn==8 & spauss==1 & eingeb==1 & mig==.
replace sa=sa1     if brdborn==8 & spauss==1 & eingeb==1 & mig==25
replace sa_erw=sa3 if brdborn==8 & spauss==1 & eingeb==1 & mig==25
replace sa_erw=sa2 if brdborn==8 & spauss==1 & eingeb==1 & sa_erw==. & mig==25
replace sa_erw=99  if brdborn==8 & spauss==1 & eingeb==1 & sa_erw==. & mig==25

* Spaetaussiedler ohne Einbuergerung
replace mig=21     if brdborn==8 & spauss==1 & eingeb==0 & mig==. 
replace sa=sa1     if brdborn==8 & spauss==1 & eingeb==0 & mig==21.
replace sa_erw=sa3 if brdborn==8 & spauss==1 & eingeb==0 & mig==21.
replace sa_erw=sa2 if brdborn==8 & spauss==1 & eingeb==0 & sa_erw==. & mig==21
replace sa_erw=99  if brdborn==8 & spauss==1 & eingeb==0 & sa_erw==. & mig==21

* kein Spaetaussiedler ...
* A3) Eingebuergerte/r 
replace mig=31     if brdborn==8 & spauss==0 & eingeb==1 & mig==.
replace sa=sa1     if brdborn==8 & spauss==0 & eingeb==1 & mig==31
replace sa_erw=sa3 if brdborn==8 & spauss==0 & eingeb==1 & mig==31
replace sa_erw=sa2 if brdborn==8 & spauss==0 & eingeb==1 & sa_erw==. & mig==31
replace sa_erw=99  if brdborn==8 & spauss==0 & eingeb==1 & sa_erw==. & mig==31

* ... Deutsche/r durch Geburt 
* A4) Vertriebener vor 1950
replace mig=11     if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & mig==.
replace sa=sa1     if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & mig==11
replace sa_erw=sa1 if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & mig==11

* A5) Aussiedler-Aequivalent 
replace mig=21     if brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & mig==.
replace sa=sa1     if brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & mig==21
replace sa_erw=sa3 if brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & mig==21
replace sa_erw=sa2 if brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & sa_erw==. & mig==21
replace sa_erw=99  if brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & sa_erw==. & mig==21

* ... Zuzugsjahr missing: Zuzug ohne Angabe zum Jahr d.h. kann Vertriebener oder Spaetaussiedler sein
* Annahme 1: wenn nach 1949 geboren, als Spaetaussiedler zugewandert
replace mig=21     if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==.
replace sa=sa1     if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==21
replace sa_erw=sa3 if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==21
replace sa_erw=sa2 if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & sa_erw==. & mig==21
replace sa_erw=99  if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & sa_erw==. & mig==21

* Annahme 2: Wenn vor 1949 geboren und keine auslaendische SA dann Vertriebener 
replace mig=11     if brdborn==8 & spauss==0 & eingeb==0 & gebj<=1949 & sadopp==0 & sa1==0 & mig==.
replace sa=sa1     if brdborn==8 & spauss==0 & eingeb==0 & gebj<=1949 & sadopp==0 & sa1==0 & mig==11
replace sa_erw=sa1 if brdborn==8 & spauss==0 & eingeb==0 & gebj<=1949 & sadopp==0 & sa1==0 & mig==11

* Annahme 3: sonst Zuzug als Spaetaussiedler ohne Datumsangabe: 29 
replace mig=29     if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==.
replace sa=sa1     if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29
replace sa_erw=sa3 if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29
replace sa_erw=sa2 if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & sa_erw==. & mig==29
replace sa_erw=99  if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & sa_erw==. & mig==29

* B) im Inland geboren: 
* B1) als Auslaender in D geboren 
replace mig=42     if brdborn==1 & ausl==1 & mig==.
replace sa=sa1     if brdborn==1 & ausl==1 & mig==42
replace sa_erw=sa1 if brdborn==1 & ausl==1 & mig==42

* B2) Spaetaussiedler/in, Fehler! 
replace mig=77     if brdborn==1 & spauss==1 & mig==.
replace sa=sa1     if brdborn==1 & spauss==1 & mig==77
replace sa_erw=sa3 if brdborn==1 & spauss==1 & mig==77
replace sa_erw=sa2 if brdborn==1 & spauss==1 & sa_erw==. & mig==77
replace sa_erw=99  if brdborn==1 & spauss==1 & sa_erw==. & mig==7

* B3) Eingebuergerte/r 
replace mig=32     if brdborn==1 & eingeb==1 & mig==.
replace sa=sa1     if brdborn==1 & eingeb==1 & mig==32
replace sa_erw=sa3 if brdborn==1 & eingeb==1 & mig==32
replace sa_erw=sa2 if brdborn==1 & eingeb==1 & sa_erw==. & mig==32
replace sa_erw=99  if brdborn==1 & eingeb==1 & sa_erw==. & mig==32
* replace mig=31     if brdborn==1 & eingeb==1 & ef5b==1   & mig==32 // Fassung fuer Jahresueberhang
* --- Unterschied Jahresbestand (MIG=32) vs. Jahresueberhang (MIG=31) im SUF aufgehoben (23.08.2012) ---

* B4) in Deutschland geborener Deutscher 
replace mig=77     if brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & mig==.
replace sa=sa1     if brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & mig==77
replace sa_erw=sa2 if brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & mig==77
replace sa_erw=sa1 if brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & sa_erw==. & mig==77

* BRDBorn=9: keine Auskunft; kommt wohl nicht vor 
replace mig=99     if brdborn==9 & mig==.
replace sa=sa1     if brdborn==9 & mig==99
replace sa_erw=sa3 if brdborn==9 & mig==99
replace sa_erw=sa1 if brdborn==9 & sa_erw==. & mig==99

* KONTROLLE Mig-Status vor Plausibilisierungen
* tab1 mig sa sa_erw, miss


/* ============================================================================
Wenn Zuwanderer angibt, eingebuergert zu sein (mig=31), dann pruefen, ob ggf. 
Spaetaussiedlerstatus vorliegt:
    a) Ehegatte ist Spaetaussiedler (MIG[Ehegatte]=21-29)
    b) Vater ist Spaetaussiedler (MIG[Vater]=21-29)
    c) Mutter ist Spaetaussiedler (MIG[Mutter]=21-29) 

Nachfolgende Pruefungen der Gruppe der Zuwanderer mit Angaben zu einer 
Einbuergerung, ob ggf. ein Spaetaussiedlerstatus vorliegt, gehen von 
dieser Definition valider Spaetaussiedler (ex: 02Vorlauf.sas) aus:
   EF366 = 8                 (Geburtsland nicht BRD)  
   & (EF372 = 2 | EF372 = 4) (Besitz der deutschen Staatsangeh. 
                              als (Spaet-)Aussiedler mit (2) oder 
                              ohne (4) Einbuergerung)  
   & JZuzug>1949             (Zuzugsjahr nach 1949) */
* ----------------------------------------------------------------------------

* A) PLAUSIBILISIERUNG - EHEGATTE 

*  Valide Spaetaussiedler (~ 02Vorlauf.sas):   
gen vorl = (ef366==8 & (ef372==2 | ef372==4) & jzuzug>1949) 
label var vorl "Valide Spaetaussiedler - PERSON"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

* EHEGATTEN IM HAUSHALT
keep if ef50==1  // Ehegatte im Haushalt
keep  ef1 ef3 v4 ef5a ef50 mig vorl jzuzug ef366 ef372 
rename ef5a   ef5_E
rename jzuzug jzuzug_E
rename ef366  ef366_E
rename ef372  ef372_E
rename mig    mig_E
rename vorl   vorl_E

sort ef1 ef3 v4 ef5_E ef50
save temp_E.dta, replace

* GESAMTFILE 
use temp.dta, clear
gen ef5_E = ef51 * (ef50==1)
label var ef5_E "Nr. des Ehepartners im Haushalt (ef51)"

* Sortierung fuer Zusammenspielen Ehegatten
sort ef1 ef3 v4 ef5_E ef50

* Angaben der Ehegatten zusammenspielen 
merge m:m ef1 ef3 v4 ef5_E ef50 using temp_E.dta
tab _merge ef50, miss 
drop _merge

* Sortierung Ausgangsfile
sort ef1 ef3 v4 ef5a

replace mig=22 if (mig==31     /// Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31) 
                 & jzuzug>10   /// und valides Zuzugsjahr 
                 & ef50==1     /// Ehegatte im Haushalt (ergaenzt) 
                 & (abs(jzuzug-jzuzug_E)<3) /// Diff +- 3 Jahre zum Zuzugsjahr des Ehegatten 
                 & vorl_E==1)               //  Ehegatte ist valider Spaetaussiedler
* n=116 Rekodierungen MIG=31 -> MIG=22
* ----------------------------------------------------------------------------

* B) PLAUSIBILISIERUNG - VATER 
*    EF54 Vater im Haushalt: fuer Ledige: 1=ja 8=nein 0=entf.
*    EF55 Nr. des Vaters im Haushalt 

gen vnr = ef55 if (ef54==1)
label var vnr "Personennr. des Vaters (ef55)"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

keep if ef54==1
keep ef1 ef3 v4 vnr

* ==> Sortierung ... vnr
sort ef1 ef3 v4 vnr
rename vnr ef5a
gen v_kids=1
collapse (count) v_kids, by(ef1 ef3 v4 ef5a)
label var v_kids "Anzahl lediger Kinder eines Vaters"
save temp_V1.dta, replace

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 ef5a

* Anzahl der Kinder den Vaetern zuspielen 
merge m:m ef1 ef3 v4 ef5a using temp_V1.dta
* tab _merge, miss
drop _merge

recode v_kids (1/99=1), gen(vater)
label var vater "Vater lediger Kinder im HH"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

keep if (vater==1)
keep  ef1 ef3 v4 ef5a mig vorl jzuzug ef366 ef372 
rename ef5a   vnr
rename jzuzug jzuzug_V
rename ef366  ef366_V
rename ef372  ef372_V
rename mig    mig_V
rename vorl   vorl_V

sort ef1 ef3 v4 vnr
save temp_V1.dta, replace

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 vnr

* Angaben des Vaters zuspielen 
merge m:m ef1 ef3 v4 vnr using temp_V1.dta
* tab _merge ef54, miss
drop _merge
* tab mig_V vater

* Sortierung des Ausgangsfiles wieder herstellen
sort ef1 ef3 v4 ef5a

replace mig=22 if (mig==31      /// Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31)
                 & jzuzug>10    /// und valides Zuzugsjahr
                 & ef54==1      /// Vater im Haushalt (ergaenzt)
                 & (abs(jzuzug-jzuzug_V)<3)  /// Diff +- 3 Jahre zum Zuzugsjahr des Vaters
                 & vorl_V==1)   //  Vater ist valider Spaetaussiedler:= EF366 = 8 & (EF372=2 | EF372=4) & JZuzug>1949
* n=20 Rekodierungen MIG=31 -> MIG=22
* ----------------------------------------------------------------------------

* C) PLAUSIBILISIERUNG - MUTTER 
*    EF52 Mutter im Haushalt: fr Ledige: 1=ja 8=nein 0=entf
*    EF53 Nr. der Mutter im Haushalt 
gen mnr = ef53 if (ef52==1)
label var mnr "Personennr. der Mutter (ef53)"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

keep if ef52==1
keep ef1 ef3 v4 mnr

* ==> Sortierung ... mnr
sort ef1 ef3 v4 mnr
rename mnr ef5a
gen m_kids=1
collapse (count) m_kids, by(ef1 ef3 v4 ef5a)
label var m_kids "Anzahl lediger Kinder einer Mutter"
save temp_M1.dta, replace

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 ef5a

* Anzahl der Kinder den Muettern zuspielen 
merge m:m ef1 ef3 v4 ef5a using temp_M1.dta
* tab _merge ef52, miss
drop _merge

recode m_kids (1/99=1), gen(mutter)
label var mutter "Mutter lediger Kinder im HH"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

keep if (mutter==1)
keep  ef1 ef3 v4 ef5a mig vorl jzuzug ef366 ef372 
rename ef5a   mnr
rename jzuzug jzuzug_M
rename ef366  ef366_M
rename ef372  ef372_M
rename mig    mig_M
rename vorl   vorl_M

sort ef1 ef3 v4 mnr
save temp_M1.dta, replace

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 mnr

* Angaben der Mutter zuspielen 
merge m:m ef1 ef3 v4 mnr using temp_M1.dta
* tab _merge ef52, miss
drop _merge
* tab mig_M mutter

* Sortierung Ausgangsfile
sort ef1 ef3 v4 ef5a

replace mig=22 if (mig==31      /// Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31)
                 & jzuzug>10    /// und valides Zuzugsjahr
                 & ef52==1      /// Mutter im Haushalt (ergaenzt)
                 & (abs(jzuzug-jzuzug_M)<3)  /// Diff +- 3 Jahre zum Zuzugsjahr der Mutter
                 & vorl_M==1)   //  Mutter ist valider Spaetaussiedler:= EF366 = 8 & (EF372=2 | EF372=4) & JZuzug>1949
* n=6 Rekodierungen MIG=31 -> MIG=22
* ----------------------------------------------------------------------------

* Kontrolle MIG-Status nach Plausibilisierung
* tab1 mig sa_erw, miss

* gen mig2 = mig 
* label var mig2 "Migrationsstatus Grundtypisierung - nach Plausibilisierung - vor Endtypisierung Eltern"
* format mig2 %2.0f


/* ====================================================================
2. Identifikation von 3-Generationen-Haushalten
   Fuer die nachfolgende Typisierung des Migrationshintergrundes
   von Eltern unter Verwendung von Angaben der Grosseltern werden
   in diesem Schritt 3-Generationen-Haushalte identifiziert und
   Identifikatoren fuer Grossmuetter- und -vaeter gebildet. */

* Sortierung Ausgangsfile   
sort ef1 ef3 v4 ef5a

* Eltern (Mutter oder Vater) mit Angaben zur (Gross-)Mutter: Personennummer der Grossmutter
generate gmnr = ( (mutter==1 | vater==1) & ef52==1) * ef53

* Eltern (Mutter oder Vater) mit Angaben zum (Gross-)Vater: Personennummer des Grossvaters
generate gvnr = ( (mutter==1 | vater==1) & ef54==1) * ef55

egen min_gmnr = min(gmnr * (gmnr>0)), by(ef1 ef3 v4)
egen max_gmnr = max(gmnr * (gmnr>0)), by(ef1 ef3 v4)
egen min_gvnr = min(gvnr * (gvnr>0)), by(ef1 ef3 v4)
egen max_gvnr = max(gvnr * (gvnr>0)), by(ef1 ef3 v4)

* Kontrolle: mehr als 1 Grossmutter(nummer) im HH?
* [Voraussetzung fuer Verwendung von "min" und "max"]
tab max_gmnr min_gmnr if max_gmnr!=min_gmnr & (min_gmnr>0)

* Kontrolle: mehr als 1 Grossvater(nummer) im HH?
tab max_gvnr min_gvnr if max_gvnr!=min_gvnr & (min_gvnr>0)

/* Kontrolle: mehr als 1 Grossvater/-mutter (nummer) im HH?
list ef3 ef4 ef5a ef44 ef46 ef52 ef53 mutter gmnr  max_gmnr ef54 ef55 gvnr max_gvnr ///
    if ( (max_gmnr!=min_gmnr & (min_gmnr>0))    ///
       | (max_gvnr!=min_gvnr & (min_gvnr>0)) ), ///
   nolab noobs sepby(ef1 ef3 ef4) 
list ef3 ef4 ef5a ef5b ef44 ef46 ef52 ef53 mutter gmnr max_gmnr ef54 ef55 vater gvnr max_gvnr if (ef3==8006 & ef4==2), nolab noobs
==> Korrektur unten */
   
* Grossvater-/mutter
gen gmutter = (max_gmnr==ef5a) if max_gmnr>0
gen gvater  = (max_gvnr==ef5a) if max_gvnr>0
* Korrektur (unerheblich, da mig=77)
replace gvater = . if (ef3==8006 & ef4==2)
replace vater  = . if (ef3==8006 & ef4==2 & ef5a==2)
replace v_kids = . if (ef3==8006 & ef4==2 & ef5a==2)


/* 3. Endtypisierung der Grosseltern 
      Im MZ 2008 nicht relevant, da keine Angaben zu den nicht im HH lebenden
      Eltern vorhanden, deshalb kann die Grundtypisierung verwendet werden. */
 

/* ====================================================================
4. Endtypisierung der Eltern
   Fuer jede Kombination von eigenem, vaeterlichen und muetterlichen 
   vorlaeufigen Migrationsstatus wird der resultierende endgueltige 
   Migrationsstatus zugewiesen. Diese Konversions-Prozedur wird nur fuer
   im Inland Geborene angewandt.
   Abschliessend wird die Variable erweiterte Staatsangehoerigkeit 
   (sa_erw) ggf. durch Informationen zum Vater bzw. zur Mutter ergaenzt.
*/

* Ausgangssortierung
sort ef1 ef3 v4 ef5a

egen mig_gv    = max(mig*(gvater==1)), by(ef1 ef3 v4)
egen sa1_gv    = max(sa1*(gvater==1)), by(ef1 ef3 v4)
egen sa2_gv    = max(sa2*(gvater==1)), by(ef1 ef3 v4)
egen sa3_gv    = max(sa3*(gvater==1)), by(ef1 ef3 v4)
egen sa_gv     = max(sa*(gvater==1)),  by(ef1 ef3 v4)
egen sa_erw_gv = max(sa_erw*(gvater==1)), by(ef1 ef3 v4)
* Angaben zum Status des Grossvaters nur falls der Grossvater 
*    der Vater ist, sonst SYSMIS
recode mig_gv sa1_gv sa2_gv sa3_gv sa_gv sa_erw_gv (nonmiss=.) if gvnr!=ef55

egen mig_gm    = max(mig*(gmutter==1)), by(ef1 ef3 v4)
egen sa1_gm    = max(sa1*(gmutter==1)), by(ef1 ef3 v4)
egen sa2_gm    = max(sa2*(gmutter==1)), by(ef1 ef3 v4)
egen sa3_gm    = max(sa3*(gmutter==1)), by(ef1 ef3 v4)
egen sa_gm     = max(sa*(gmutter==1)),  by(ef1 ef3 v4)
egen sa_erw_gm = max(sa_erw*(gmutter==1)), by(ef1 ef3 v4)
* Angaben zum Status der Grossmutter nur falls die Grossmutter
*   die Mutter ist, sonst SYSMIS.
recode mig_gm sa1_gm sa2_gm sa3_gm sa_gm sa_erw_gm (nonmiss=.) if gmnr!=ef53

/* --------------------------------------------------------------------
Ab hier die eigentliche Endtypisierung des Migrationsstatus der Eltern 
mittels Konversions-Prozedur, bei der nur im Inland Geborene 
beruecksichtigt werden. */

recode mig (11 21 22 23 25 29 31 41=.) (*=1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle"

* EGRE: Eltern - Grosseltern 
gen egre = ( (mutter==1 & gmnr==ef53) | (vater==1 & gvnr==ef55) )
label var egre "Eltern mit Grosseltern im Haushalt"
format konvproc egre %1.0f

* Vorbereitung MATCH Konversionstabelle
* Nur im Inland geborene Eltern mit Grosseltern
gen _mig_  = mig    if (konvproc==1 & egre==1)    // MIG-Status Eltern vor Konversion
gen _migv_ = mig_gv if (konvproc==1 & egre==1)    // MIG-Status Grossvater
gen _migm_ = mig_gm if (konvproc==1 & egre==1)    // MIG-Status Grossmutter
replace _migm_ = 99 if (konvproc==1 & egre==1 & _migm_==.)
replace _migv_ = 99 if (konvproc==1 & egre==1 & _migv_==.)
format _mig_ _migv_ _migm_ %2.0f


/* conversion.dta (ex conversion_2011.xls)
 obs:         1,163
 vars:            6
variable name   variable label
---------------------------------------------------------
_mig_           Migrationsstatus Befragter VOR Konversion
_migv_          Migrationsstatus Vater
_migm_          Migrationsstatus Mutter
konvproc        Konstante (1) fuer Konversionsprozedur
migneu          Migrationsstatus Befragter konvertiert
kennung                           
*/

* Sortierung fuer Match mit Konversionsprozedur
sort _mig_ _migv_ _migm_ konvproc

merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
drop _merge

* Ausgangssortierung
sort ef1 ef3 v4 ef5a


gen mig2 = mig 
label var mig2 "Migrationsstatus vor Endtypisierung Eltern"
format mig2 %2.0f

* Uebernahme konvertierter MIG-Typisierung
gen mig3 = migneu if (migneu!=.)
replace mig3 = mig2 if (migneu==.)
label var mig3 "Migrationsstatus nach Endtypisierung Eltern"
format mig3 %2.0f


* Aenderungen
* tab mig3 mig2 if mig3!=mig2, miss

/* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag 
        ergaenzen, sofern noetig und moeglich 
   SA_erw zur Kontrolle der Rekodierung als SA_erw0 sichern */
gen sa_erw0 = sa_erw
* Nur im Inland geborene Eltern (ohne Grosseltern): KonvProc=1
replace sa_erw = sa_erw_gv if (konvproc==1 & ((vater==1  & (gvater==0  | gvater==.) ) |   ///
                                              (mutter==1 & (gmutter==0 | gmutter==.)) ) & ///
                             ( (sa_erw==0 | sa_erw==99) & (sa_erw_gv>0 & sa_erw_gv<99) ) )
replace sa_erw = sa_erw_gm if (konvproc==1 & ((vater==1  & (gvater==0  | gvater==.) ) |   ///
                                              (mutter==1 & (gmutter==0 | gmutter==.)) ) & ///
                              ( (sa_erw==0 | sa_erw==99) & (sa_erw_gm>0 & sa_erw_gm<99) ) )


* Aenderungen
* tab sa_erw sa_erw0 if sa_erw!=sa_erw0, miss

* Ausgangssortierung
sort ef1 ef3 v4 ef5a

* Kontrollvariable sa_erw0 loeschen
drop sa_erw0

* Variablen aus conversion.dta loeschen
drop _mig_ _migv_ _migm_ konvproc migneu kennung 

* Zwischenspeicherung MIG nach Endtypisierung der Eltern
save temp_mig3.dta, replace 

/* ===========================================================================
5. Endtypisierung Befragte 
   Analog zur Endtypisierung der Eltern wird der endgueltige Migrationsstatus 
   unter Beruecksichtigung der Kombinationen von eigenem, vaeterlichen und 
   muetterlichen vorlaeufigen Migrationsstatus zugewiesen, wobei auch hier 
   die Zuweisungen nur fuer die im Inland Geborenen zur Anwendung kommen, und
   die erweiterte Staatsangehoerigkeit (SA_erw) ggf. durch Angaben des Vaters 
   bzw. der Mutter ergaenzt wird.
   Die Variable SA_erw ist Basis der Staatsangehoerigkeit zum 
   Migrationsstatus (MIGS). */

* Migrationsrelevante Eintraege fuer Vaeter: MIG3 SA1 SA2 SA3 SA SA_erw JZuzug

keep if vater==1
keep ef1 ef3 v4 ef5a mig3 sa1 sa2 sa3 sa sa_erw jzuzug
rename ef5a    vnr 
rename mig3    mig_v
rename sa1     sa1_v
rename sa2     sa2_v
rename sa3     sa3_v
rename sa      sa_v
rename sa_erw  sa_erw_v
rename jzuzug  jzuzug_v

sort ef1 ef3 v4 vnr
save temp_V.dta, replace


* GESAMTFILE 
use temp_mig3.dta, clear
sort ef1 ef3 v4 vnr
* Angaben des Vaters zuspielen 
merge m:m ef1 ef3 v4 vnr using temp_V.dta
* tab _merge ef54
drop _merge
* tab mig_v vater, miss

* Ausgangssortierung
sort ef1 ef3 v4 ef5a

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp_mig3.dta, replace

* ---------------------------------------------------------------- 
* Migrationsrelevante Eintraege fuer Muetter

preserve
keep if mutter==1
keep ef1 ef3 v4 ef5a mig3 sa1 sa2 sa3 sa sa_erw jzuzug
rename ef5a    mnr 
rename mig3    mig_m
rename sa1     sa1_m
rename sa2     sa2_m
rename sa3     sa3_m
rename sa      sa_m
rename sa_erw  sa_erw_m
rename jzuzug  jzuzug_m
sort ef1 ef3 v4 mnr
save temp_M.dta, replace
restore

* GESAMTFILE 
use temp_mig3.dta, clear
sort ef1 ef3 v4 mnr

* Angaben der Mutter zuspielen 
merge m:m ef1 ef3 v4 mnr using temp_M.dta
* tab _merge ef52
drop _merge

* tab mig_m mutter, miss


* Zwischenspeicherung Gesamtfile
sort ef1 ef3 v4 ef5a
save temp.dta, replace



* ---------------------------------------------------------------- 
* Konversions-Prozedur nur fuer im Inland Geborene 
recode mig3 (11 21 22 23 25 29 31 41=.) (else=1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle"

* Vorbereitung MATCH Konversionstabelle
generate _mig_  = mig3  if konvproc==1  // MIG-Status Person vor Konversion
generate _migv_ = mig_v if konvproc==1 & vnr==ef55 // Angaben zum Vater
generate _migm_ = mig_m if konvproc==1 & mnr==ef53 // Angaben zur Mutter
replace  _migm_ = 99    if konvproc==1 & mnr!=ef53 // Angaben nur zum Vater
replace  _migv_ = 99    if konvproc==1 & vnr!=ef55 // Angaben nur zur Mutter
recode   _migv_ _migm_ (22 23 = 21) if konvproc==1
format _mig_ _migv_ _migm_ %2.0f

* Konversionstabelle zuspielen 
sort _mig_ _migv_ _migm_ 
merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
drop _merge

* Ausgangssortierung
sort ef1 ef3 v4 ef5a

* neu, da durch Match ggf. ueberschrieben
drop konvproc
recode mig3 (11 21 22 23 25 29 31 41=.) (*=1), gen(konvproc)

* Migrationsstatus NACH Konversion zuweisen
generate mig4 = mig3
replace  mig4 = migneu if (konvproc==1 & migneu!=.)
label var mig4 "Migrationsstatus nach Endtypisierung Befragte"
format mig4 %2.0f


* loeschen mig: Migrationsstatus vor Endtypisierung Eltern (=> mig2)
drop mig


* 6. Umsetzung von Zeitreihenkompatibilitaet entfaellt im MZ 2008 


/* ===========================================================================
7. Variablendefinitionen wie im SUF und fuer Fachserien-Ergebnisse         */

* Recodierungen wie SUF
recode mig4 (0 77=0) (29 21=21), gen(mig) copyrest
label var mig "Migrationsstatus nach Endtypisierung Befragte"
format mig %2.0f
* SUF Value Labels 
label def mig ///
  0 "[0] Deutsch ohne Mig-hintergrund(0); uneindeutig ob deutsch, vertrieben oder Spaetaussiedler(77)" ///
 11 "[11] Bis einschl. 1949 als Deutscher ohne Einbuergerung auf das heutige Bundesgebiet zugewandert" ///
 21 "[21] 21/29: 1950 und spaeter als Deutscher ohne Einbuergerung auf das heutige Bundesgebiet zugewandert(Spaetaussiedler)(21); (Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr(29)" /// 
 22 "[22] Ehegatte oder Kind von Spaetaussiedler, zeitgleich eingereist" /// 
 25 "[25] Spaetaussiedler mit formaler Einbuergerung" /// 
 31 "[31] Als Auslaender auf das heutige Bundesgebiet zugewandert und zwischenzeitlich eingebuergert" /// 
 32 "[32] Als Auslaender im heutigen Bundesgebiet geboren und zwischenzeitlich eingebuergert" /// 
 41 "[41] Als Auslaender auf das heutige Bundesgebiet zuwandert" /// 
 42 "[42] Als Auslaender im heutigen Bundesgebiet geboren, entweder beide Eltern als Auslnder zugewandert oder der eine Elternteil" /// 
 43 "[43] Als Auslaender im heutigen Bundesgebiet geboren, beide Eltern im heutigen Bundesgebiet geboren" /// 
 52 "[52] Deutscher mit einseitigem Mig-hintergrund; Mig-status durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 53 "[53] Deutscher mit einseitigem Mig-hintergrund; Mig-status durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 54 "[54] Deutscher mit einseitigem Mig-hintergrund; Mig-sstatus durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 62 "[62] Deutscher mit beidseitigem Mig-hintergrund; Mig-status durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 63 "[63] Deutscher mit beidseitigem Mig-hintergrund; Mig-status durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 64 "[64] Deutscher mit beidseitigem Mig-hintergrund; Mig-status durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 77 "[77] uneindeutig ob deutsch, vertrieben oder Spaetaussiedler" 
label val mig mig

* KONTROLLE
* tab mig, miss


* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag ergaenzen, 
*        sofern noetig und moeglich
replace sa_erw = sa_erw_v if (konvproc==1 & vnr==ef55 & (sa_erw==0 | sa_erw==99) & (sa_erw_v>0 & sa_erw_v<99))
replace sa_erw = sa_erw_m if (konvproc==1 & mnr==ef53 & (sa_erw==0 | sa_erw==99) & (sa_erw_m>0 & sa_erw_m<99))


/* ===================== MIGS ======================= 
Recodierung sa_erw => migs 

Keine einheitliche Recodierung aufgrund unterschiedlicher Vergroebung 
der Variablen zu Staatsangehoerigkeiten moeglich; s.o.
Auch nach Harmonisierung koennen Differenzen zu Ergebnissen der 
Fachserie damit zusammenhaengen, dass im SUF keine differenzierten
Angaben zur 2. Staatsangehoerigkeit vorliegen.
*/
generate migs = sa_erw
replace  migs = 0 if (mig==0)
format migs %2.0f
label var migs "Staatsangehoerigkeit: Migrationsstatus"
label def migs ///
    0 "[0] Deutsch ohne Migrationshintergrund" ///
    2 "[2] Bosnien und Herzegowina" ///
    4 "[4] 4/8/27: Dnemark(4); Finnland(8); Schweden(27)" ///
    5 "[5] Ehemalige Sowjetunion" ///
    6 "[6] Ehemaliges Jugoslawien" ///
    9 "[9] Frankreich" ///
   10 "[10] Griechenland" ///
   13 "[13] Italien" ///
   14 "[14] Kroatien" ///
   21 "[21] 1/18/21: Belgien(1); Luxemburg(18); Niederlande(21)" ///
   22 "[22] sterreich" ///
   23 "[23] Polen" ///
   24 "[24] Portugal" ///
   25 "[25] 3/25: Bulgarien(3); Rumnien(25)" ///
   26 "[26] Russische Fderation" ///
   28 "[28] 12/16/20/28: Island(12); Liechtenstein(16); Norwegen(20); Schweiz(28)" ///
   31 "[31] 7/15/17/19/31/37: Estland(7); Lettland(15); Litauen(17); Malta(19); Slowenien(31); Zypern(37)" ///
   32 "[32] Spanien" ///
   33 "[33] 30/33: Slowakei(30); Tschechische Republik(33)" ///
   34 "[34] Trkei" ///
   35 "[35] Ungarn" ///
   36 "[36] 11/36: Irland(11); Vereinigtes Knigreich(36)" ///
   38 "[38] Sonstiges Osteuropa" ///
   39 "[39] Sonstiges Europa" ///
   40 "[40] Marokko" ///
   41 "[41] Sonstiges Nordafrika" ///
   42 "[42] Sonstiges Afrika (ohne Marokko)" ///
   43 "[43] Vereinigte Staaten von Amerika (USA)" ///
   45 "[45] 44/45: Sonstiges Nordamerika [Kanada](44); Mittelamerika und Karibik(45)" ///
   46 "[46] Sdamerika" ///
   47 "[47] Irak" ///
   48 "[48] Iran" ///
   49 "[49] Sonstiger Naher und Mittlerer Osten (ohne Iran)" ///
   50 "[50] Vietnam" ///
   51 "[51] Afghanistan" ///
   52 "[52] Sonstiges Sd- und Sdostasien" ///
   53 "[53] China" ///
   54 "[54] Sonstiges Ostasien" ///
   55 "[55] 55/98: brige Welt(55); Staatenlos(98)" ///
   56 "[56] Ukraine" ///
   57 "[57] Kasachstan" ///
   58 "[58] Serbien" ///
   59 "[59] Montenegro" 
label val migs migs   
* tab migs, miss

* ======= ENDE MIG-TYPISIERUNG ===== 

/* Variablendefinitionen fuer Fachserien-Ergebnisse
MIGRATIONSTYP => Definitionen fuer Bevoelkerung am Hauptwohnsitz
Z# : Lfd. Nr. in Tab. 2 */
recode mig (0/77=1) (else=.), gen(Z001) 
recode mig (0 11 77=1) (else=.), gen(Z002)
recode mig (21/29 31 32 41/43 52/54 62/64=1) (else=.), gen(Z005)
recode mig (21/29 31 41=1) (else=.), gen(Z034)
recode mig (41=1) (else=.), gen(Z062)
recode mig (21 22 25 29 31=1) (else=.), gen(Z089)
recode mig (21 22 25 29=1) (else=.), gen(Z090)
recode mig (31=1) (else=.), gen(Z097)
recode mig (42 43 32 52/54 62/64=1) (else=.), gen(Z119)
recode mig (42 43=1) (else=.), gen(Z126)
recode mig (32 52/54 62/64=1) (else=.), gen(Z133)
recode mig (32=1) (else=.), gen(Z134)
recode mig (52/54 62/64=1) (else=.), gen(Z140)
recode mig (62/64=1) (else=.), gen(Z141)
recode mig (52/54=1) (else=.), gen(Z142)
format Z001-Z142 %1.0f
label var Z001 "Bevoelkerung insgesamt"
label var Z002 "Personen ohne Mig-hintergrund"
label var Z005 "Personen mit Mig-hintergrund i.e.S."
label var Z034 "Personen mit eigener Mig-erfahrung"
label var Z062 "+ Auslaender"
label var Z089 "+ Deutsche"
label var Z090 "  - Spaetaussiedler"
label var Z097 "  - durch Einbuergerung"
label var Z119 "Personen ohne eigene Mig-erfahrung"
label var Z126 "+ Auslaender"
label var Z133 "+ Deutsche"
label var Z134 "  - durch Einbuergerung"
label var Z140 "  - mit mind. 1 zugew. o. als Ausl. in D geb. Elternteil"
label var Z141 "    # mit beidseitigem Mig-hintergrund"
label var Z142 "    # mit einseitigem Mig-hintergrund"

/* =========== STAATSANGEHOERIGKEITEN =================================
Bei Vergleichen von migs mit Tab. 2 Fachserie 1, Reihe 2.2, ist zu 
beachten, dass die Staatsangehoerigkeit deutscher Zuwanderer ohne 
Einbuergerung sowie in Deutschland geborener Deutscher mit ein-/
beidseitigem Migrationshintergund in 0 (deutsch) recodiert werden muss.
Z. B. */
generate MIGS_R = migs
replace  MIGS_R = 0 if mig==0 | mig==11 | (mig>=21 & mig<=29) | (mig>=61 & mig<=64) | (mig>=71 & mig<=74)
/* Staatsangehoerigkeiten (MIGS_R) - Tab. 2 FS 1, R 2.2 
- Personen mit Migrationshintergrund im engeren Sinn  - 
Z## :  Lfd. Nr. in Tab. 2 */
recode MIGS_R (0/99=1) (*=.), gen(Z00)
recode MIGS_R (01/39 56/59=1) (*=.), gen(Z06)
recode MIGS_R (4 9 10 13 21/25 31 32 33 35 36=1) (*=.), gen(Z07)
recode MIGS_R (10=1) (*=.), gen(Z08)
recode MIGS_R (13=1) (*=.), gen(Z09)
recode MIGS_R (23=1) (*=.), gen(Z10)
recode MIGS_R (2 5 6 14 26 28 34 38 39 56/59=1) (*=.), gen(Z12)
recode MIGS_R (2=1) (*=.), gen(Z13)
recode MIGS_R (14=1) (*=.), gen(Z14)
recode MIGS_R (26=1) (*=.), gen(Z15)
recode MIGS_R (58 59=1) (*=.), gen(Z16)
recode MIGS_R (34=1) (*=.), gen(Z17)
recode MIGS_R (56=1) (*=.), gen(Z18)
recode MIGS_R (40/42=1) (*=.), gen(Z19)
recode MIGS_R (43/46=1) (*=.), gen(Z20)
recode MIGS_R (47/54 57=1) (*=.), gen(Z22)
recode MIGS_R (47 48 49 57=1) (*=.), gen(Z23)
recode MIGS_R (57=1) (*=.), gen(Z24)
recode MIGS_R (50/52=1) (*=.), gen(Z25)
recode MIGS_R (0 55 98=1) (*=.), gen(Z26)
format Z00-Z26 %1.0f
label var Z00 "Insgesamt [0-99]"
label var Z06 "Europa [01-39,56-59]"
label var Z07 "o EU 27 [4,9,10,13,21-25,31-33,35,36]"
label var Z08 "  - Griechenland [10]"
label var Z09 "  - Italien [13]"
label var Z10 "  - Polen [23]"
label var Z12 "o Sonstiges Europa [2,5,6,14,26,28,34,38,39,56-59]"
label var Z13 "  - Bosnien und Herzegowina [2]"
label var Z14 "  - Kroatien [14]"
label var Z15 "  - Russische Foederation [26]"
label var Z16 "  - Serbien und Montenegro [58-59]"
label var Z17 "  - Tuerkei [34]"
label var Z18 "  - Ukraine [56]"
label var Z19 "Afrika [40-42]"
label var Z20 "Amerika [43-46]"
label var Z22 "Asien, Australien und Ozeanien [47-54,57]"
label var Z23 "o Naher und Mittlerer Osten [37-49,57]"
label var Z24 "  - Kasachstan [57]"
label var Z25 "o Sued- und Suedostasien [50-52]"
label var Z26 "Ohne Angabe bzw. unzutreffend [0,55,98]"
* Sortierung nach ID Satznummer Ausgangsfile mz2008.dta fuer Zuspielen der 
*    erstellten Variablen MIG zum Scientific Use File
sort ID

* Zwischenspeicherung.
save mig2008.dta, replace



* Kontrolle - Vergleich mit SUF 
*             mig ?=? mig_o
tab mig mig_o if mig!=mig_o, nolab
* MIG=32 vs. MIG_O=31: n=  78 --- OK, da Unterschied Jahresbestand/-berhang (in MIG_O im SUF) aufgehoben
* MIG=42 bs. MIG_O=43: n= 234 --- OK, da neue Konversionstabelle 'conversion'


* Kontrolle: migs ?=? migs - Originalvariable
tab migs migs_o if migs!=migs_o, nolab
* OK, keine Differenzen.


* Fallzahlen
tab1 mig migs, nolab


* Hochgerechnete Verteilungen von MIG und MIGS 
*    Bevoelkerung am Hauptwohnsitz
*    Hochrechnung Jahresdurchschnitt
tab mig if ef30>=1 & ef30<=2 [iw=ef952], miss


/* Vergleich mit Tabelle 2, S. 64 in: Statistisches Bundesamt, 2010: 
   Fachserie 1 Bevoelkerung und Erwerbstaetigkeit, Reihe 2.2,  
   Bevoelkerung mit Migrationshintergrund. Ergebnisse des Mikrozensus 2008. 
   Wiesbaden. 
   MIGRATIONSTYPEN
   Bevoelkerung am Hauptwohnsitz, Hochrechnung: Jahresdurchschnitt */
summ Z001-Z142 if ef30>=1 & ef30<=2 [iw=ef952], sep(0)


/* Vergleich mit Tabelle 2, S. 64 in: Statistisches Bundesamt, 2010: 
   Fachserie 1 Bevoelkerung und Erwerbstaetigkeit, Reihe 2.2, 
   Bevoelkerung mit Migrationshintergrund. Ergebnisse des Mikrozensus 2008. 
   Wiesbaden. 
   STAATSANGEHOERIGKEITEN
   ZU BEACHTEN: Aufgrund fehlender differenzierter Angaben zur  
   2. Staatsangehoerigkeit (EF370) koennen Abweichungen zur Fachserie auftreten. 
   Bevoelkerung am Hauptwohnsitz, Hochgerechnung: Jahresdurchschnitt,
   Personen mit Migrationshintergrund im engeren Sinn (Z005: mig=21-64) */ 
summ Z00-Z26 if ef30>=1 & ef30<=2 & mig>=21 & mig<=64 [iw=ef952], sep(0)

* ################################################################################
* PROGRAMMENDE

exit
